# -*- coding: utf-8 -*-

import json

import click

from em_tasks.utils.offer_services import AmzOfferService
from em_tasks.tools.amz_product_seeds_exporter import AmzProductSeedsExporter
from em_tasks.store.models import *

from em_celery import logger, get_product_service


@click.command('Export Amazon product seeds.')
@click.option('-m', '--marketplace', required=True, type=str, default='us', help='Amazon marketplace.')
@click.option('-po', '--missing_info_output_path', required=True, type=str, help='Products missing information output file path')
@click.option('-o', '--missing_offer_output_path', required=True, type=str, help='Products missing offer output file path')
@click.option('-d', '--days', type=int, default=None, help='Days of products to process.')
def export_seeds(marketplace, missing_info_output_path, missing_offer_output_path, days=None):
  missing_info_output_path = os.path.abspath(os.path.expanduser(missing_info_output_path))
  output_dir = os.path.dirname(missing_info_output_path)
  if not os.path.isdir(output_dir):
    os.makedirs(output_dir)

  missing_offer_output_path = os.path.abspath(os.path.expanduser(missing_offer_output_path))
  output_dir = os.path.dirname(missing_offer_output_path)
  if not os.path.isdir(output_dir):
    os.makedirs(output_dir)

  product_service = get_product_service()

  seeds_exporter = AmzProductSeedsExporter(marketplace, product_service, missing_info_output_path, missing_offer_output_path, days)
  seeds_exporter.run()


if __name__ == '__main__':
  export_seeds()
