# -*- coding: utf-8 -*-

import datetime
import json

import click

from em_celery import logger, init_db
from em_tasks.store.store_util import StoreUtil
from em_tasks.spree.api import SpreeApi
from em_tasks.utils.blacklist_filter import BlacklistFilter
from em_tasks.store.models import *

from em_celery import logger, init_db


@click.command('Import products to Spree')
@click.option('-s', '--store_code', type=str, required=True)
@click.option('-ms', '--min_shipping_days', type=int, default=7, help='Minimum shipping days, default is 7.')
@click.option('-tn', '--taxonomy_name', type=str, default='Categories', help='Spree taxonomy name, default is "Categories".')
@click.option('-m', '--merchant_id', required=True, type=str, help='Google Merchant ID to upload to.')
@click.option('-v', '--vendor_id', required=True, type=str, help='Vendor ID that products belongs to.')
@click.option('-tc', '--tax_category_id', type=int, default=1, help='Spree tax category ID, default is 1.')
@click.option('-sl', '--stock_location_id', required=True, type=int, help='Spree stock location ID.')
@click.option('-sc', '--shipping_category_id', required=True, type=int, help='Spree shipping category ID.')
@click.argument('products_path')
def import_products(store_code, products_path, shipping_category_id, stock_location_id, merchant_id, vendor_id, tax_category_id=1, taxonomy_name='Categories', min_shipping_days=7):
  init_db()

  if not products_path:
    return

  products_path = os.path.abspath(os.path.expanduser(products_path))
  if not os.path.isfile(products_path):
    return

  store = StoreUtil.get_store_by_code(store_code)
  if not store:
    return

  blacklist_filter = BlacklistFilter()

  credential = json.loads(store.api_credential)
  spree_api = SpreeApi(credential['endpoint'], credential['api_key'], credential.get('api_version', 'v1'))
  # spree_api = SpreeApi('http://localhost:3000', credential['api_key'], credential.get('api_version', 'v1'))

  batch_size = 50
  products_buf = []
  with open(products_path, encoding='utf-8', errors='ignore') as fh:
    for line in fh:
      s = line.strip()
      if not s:
        continue

      prod = None
      try:
        prod = json.loads(s)
      except Exception as e:
        logger.exception(e)

      if not prod:
        continue

      s = '{}-{}'.format(prod.get('title', '').lower(), prod.get('brand', '').lower())
      result = blacklist_filter.is_blacklisted(s)
      if result:
        logger.debug('[ProductFiltered] ProductID: %s, Reason: Blacklisted - %s, Title: %s', prod.get('source_product_id', ''), result, s)
        continue

      products_buf.append(prod)
      if len(products_buf) < batch_size:
        continue

      max_retries = 3
      while max_retries > 0:
        try:
          spree_api.import_products(products_buf, stock_location_id, shipping_category_id, vendor_id, merchant_id, min_shipping_days, taxonomy_name, tax_category_id)
          products_buf = []
          break
        except Exception as e:
          logger.exception(e)
          max_retries -= 1

  if products_buf:
    spree_api.import_products(products_buf, stock_location_id, shipping_category_id, vendor_id, merchant_id, min_shipping_days, taxonomy_name, tax_category_id)
  products_buf = []


if __name__ == "__main__":
  import_products()
