# -*- coding: utf-8 -*-

import json
import datetime
import re

import dateutil
import dateutil.parser

import click

from em_celery import logger, init_db
from em_tasks.store.store_util import StoreUtil
from em_tasks.google.sheet_api import SheetAPI
from em_tasks.store.models import *


@click.command('Import Sheet Orders to Spree')
@click.option('-s', '--store_code', required=True, type=str, help='Store code.')
@click.option('-sid', '--spreadsheet_id', required=True, type=str)
def rename_order_sheets(store_code, spreadsheet_id):
  init_db()

  store = StoreUtil.get_store_by_code(store_code)
  if not store:
    logger.warning('[StoreNotFound] %s', store_code)
    return

  service_account_data = json.loads(store.service_account_data)
  sheet_api = SheetAPI(service_account_data)
  spreadsheet = sheet_api.get_spreadsheet(spreadsheet_id)
  if not spreadsheet:
    logger.error('[SpreadSheetNotFound] %s', spreadsheet_id)
    return

  now = datetime.datetime.now()
  last_year = now.year - 1

  worksheets = sheet_api.get_worksheets(spreadsheet)
  for worksheet in worksheets:
    records = []
    name = worksheet.title
    try:
      sheet_date = dateutil.parser.parse(name)

      if not sheet_date or sheet_date < now:
        continue

      new_name = sheet_date.replace(year=last_year).strftime('%m/%d/%Y')
      sheet_api.retry(worksheet.update_title, new_name)
      logger.info("[RenameSheet] From: %s, To: %s", name, new_name)
    except Exception as e:
      # None date sheets
      continue


if __name__ == "__main__":
  rename_order_sheets()
