# -*- coding: utf-8 -*-

import json

import click

from em_celery import logger, init_db
from em_tasks.store.store_util import StoreUtil
from em_tasks.tools.spree.sheet_orders_importer import SheetOrdersImporter
from em_tasks.store.models import *


@click.command('Import Sheet Orders to Spree')
@click.option('-s', '--store_code', required=True, type=str, help='Store code.')
@click.option('-d', '--days', type=int, default=14, help='Import how many days order, default is 14.')
def import_orders(store_code, days=14):
  init_db()

  store = StoreUtil.get_store_by_code(store_code)
  if not store:
    logger.warning('[StoreNotFound] %s', store_code)
    return

  service_account_data = json.loads(store.service_account_data)
  importer = SheetOrdersImporter(store_code, service_account_data, days)
  importer.run()


if __name__ == "__main__":
  import_orders()
